@@ -100,6 +100,7 @@ bool CTaskBuild::CreateBuilding(Math::Vector pos, float angle)
     if ( m_type == OBJECT_PARA     )  m_buildingHeight = 68.0f;
     if ( m_type == OBJECT_INFO     )  m_buildingHeight = 19.0f;
     if ( m_type == OBJECT_DESTROYER)  m_buildingHeight = 35.0f;
+    if ( m_type == OBJECT_HUSTON   )  m_buildingHeight = 45.0f;
     m_buildingHeight *= 0.25f;
 
     m_buildingPos = m_building->GetPosition(0);
@@ -574,7 +575,7 @@ Error CTaskBuild::FlatFloor()
     if ( m_type == OBJECT_PARA     )  radius = 20.0f;
     if ( m_type == OBJECT_INFO     )  radius =  5.0f;
     if ( m_type == OBJECT_DESTROYER)  radius = 20.0f;
-    if ( radius == 0.0f )  return ERR_GENERIC;
+    //if ( radius == 0.0f )  return ERR_GENERIC;
 
     center = m_metal->GetPosition(0);
     angle = m_terrain->GetFineSlope(center);
